@@ -14,17 +14,30 @@ module.exports = grammar(CPP, {
     rules: {
         _top_level_item: (_, original) => original,
 
-        function_definition: (_, original) => seq(
-            seq(
-                repeat(
-                    choice(
-                        '__device__',
-                        '__host__',
-                        prec(10, '__global__'),
-                        '__forceinline__'
-                    )
-                ),
-            ), original
+        function_definition: ($, original) => seq(
+            repeat(
+                choice(
+                    $.launch_bounds,
+                    '__device__',
+                    '__host__',
+                    prec(10, '__global__'),
+                    '__forceinline__'
+                )
+            )
+            , original
+        ),
+
+        declaration: ($, original) => seq(
+            repeat(
+                choice(
+                    $.launch_bounds,
+                    '__device__',
+                    '__host__',
+                    prec(10, '__global__'),
+                    '__forceinline__'
+                )
+            )
+            , original
         ),
 
         call_expression: ($, original) => choice(original, seq(
@@ -43,6 +56,8 @@ module.exports = grammar(CPP, {
             '__constant__',
             '__restrict__',
         ),
+
+        launch_bounds: $ => seq("__launch_bounds__", "(", $._expression, optional(seq(",", $._expression),), ")"),
     }
 });
 
